==> rstpm2_1.5.0.tar.gz: rstpm2/vignettes/auto/multistate.el <==
(TeX-add-style-hook
 "multistate"
 (lambda ()
   (TeX-add-to-alist 'LaTeX-provided-class-options
                     '(("jss" "nojss")))
   (TeX-add-to-alist 'LaTeX-provided-package-options
                     '(("inputenc" "utf8") ("geometry" "margin=2.6cm")))
   (add-to-list 'LaTeX-verbatim-environments-local "VerbatimOut")
   (add-to-list 'LaTeX-verbatim-environments-local "SaveVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "LVerbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "LVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "BVerbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "BVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "Verbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "Verbatim")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperref")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperbaseurl")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "nolinkurl")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "url")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "path")
   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "path")
   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "Verb")
   (TeX-run-style-hooks
    "latex2e"
    "jss"
    "jss10"
    "amsmath"
    "amsfonts"
    "enumitem"
    "fancyvrb"
    "hyperref"
    "inputenc"
    "geometry"
    "wasysym"
    "bm"
    "tablefootnote"
    "algorithm2e"
    "graphicx"
    "tikz"
    "xcolor")
   (LaTeX-add-labels
    "eq:kolmogorov"
    "eq:Pinit"
    "eq:dPudt"
    "eq:Puinit"
    "eq:los"
    "eq:dLudt"
    "eq:Linit"
    "eq:utilities"
    "eq:dUudt"
    "eq:costs"
    "fig:coverage"
    "fig:coverage-los"
    "fig:1"
    "fig:2"
    "eq:hrgen"
    "eq:stratified"
    "tab:models")
   (LaTeX-add-bibliographies
    "lib"))
 :latex)

==> rstpm2_1.5.8.tar.gz: rstpm2/vignettes/auto/multistate.el <==
(TeX-add-style-hook
 "multistate"
 (lambda ()
   (TeX-add-to-alist 'LaTeX-provided-class-options
                     '(("jss" "nojss")))
   (TeX-add-to-alist 'LaTeX-provided-package-options
                     '(("inputenc" "utf8") ("geometry" "margin=2.6cm")))
   (add-to-list 'LaTeX-verbatim-environments-local "Verbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "Verbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "BVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "BVerbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "LVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "LVerbatim*")
   (add-to-list 'LaTeX-verbatim-environments-local "SaveVerbatim")
   (add-to-list 'LaTeX-verbatim-environments-local "VerbatimOut")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "href")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "path")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "url")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "nolinkurl")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperbaseurl")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperref")
   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "Verb*")
   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "Verb")
   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "path")
   (TeX-run-style-hooks
    "latex2e"
    "jss"
    "jss10"
    "amsmath"
    "amsfonts"
    "enumitem"
    "fancyvrb"
    "hyperref"
    "inputenc"
    "geometry"
    "wasysym"
    "bm"
    "tablefootnote"
    "tikz"
    "algorithm2e"
    "Sweave")
   (LaTeX-add-labels
    "eq:kolmogorov"
    "eq:Pinit"
    "eq:dPudt"
    "eq:Puinit"
    "eq:los"
    "eq:dLudt"
    "eq:Linit"
    "eq:utilities"
    "eq:dUudt"
    "eq:costs"
    "fig:coverage"
    "fig:coverage-los"
    "fig:1"
    "fig:2"
    "eq:hrgen"
    "eq:stratified"
    "tab:models")
   (LaTeX-add-environments
    '("function" LaTeX-env-args ["argument"] 0)
    '("procedure" LaTeX-env-args ["argument"] 0))
   (LaTeX-add-bibliographies
    "lib"))
 :latex)
